#
# spec file for package eksctl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           eksctl
Version:        0.157.0
Release:        1.1
Summary:        The official CLI for Amazon EKS
License:        Apache-2.0
URL:            https://github.com/weaveworks/eksctl
Source:         eksctl-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.17

%description
eksctl is a simple CLI tool for creating clusters on EKS - Amazon's new managed Kubernetes service for EC2. It is written in Go, and uses CloudFormation.

You can create a cluster in minutes with just one command – eksctl create cluster!

%prep
%setup -q
%setup -q -T -D -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-s -w -X github.com/weaveworks/eksctl/pkg/version.gitCommit=%{version} -X github.com/weaveworks/eksctl/pkg/version.buildDate=$BUILD_DATE" \
   -o bin/eksctl ./cmd/eksctl

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Fri Sep 15 2023 kastl@b1-systems.de
- Update to version 0.157.0:
  * Release notes for 0.157.0
  * Bump dependencies
  * update readme with new url of logo image
  * fix permission denied error for link checker
  * fix *** missing separator.  Stop. error
  * fix dependencies required for social cards
  * Material version updates and added social cards, cookie consent
    and feedback functionality
  * Fix `update aws node` workflow (#7045)
  * Add note on how to use `--include/exclude` flags when creating
    iamserviceaccounts (#7047)
  * Skip adding egress rules if default egress rule is present
  * Disallow passing a vpc.securityGroup with external SG rules for
    unowned clusters
  * Bump actions/checkout from 3.6.0 to 4.0.0
  * Prepare for next development iteration
* Fri Sep  8 2023 kastl@b1-systems.de
- Update to version 0.156.0:
  * Add release notes for 0.156.0 (#7033)
  * cleanup
  * Added adopters ticker for the docs
  * Cleanup subnets with invalid AZs before importing VPC from CFN
    stack (#6935)
  * Bump aws-actions/configure-aws-credentials from 2.2.0 to 3.0.1
    (#7008)
  * Update build image tag
  * Bump dependencies
  * Prepare for next development iteration
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.155.0:
  * Add release notes for 0.155
  * Improve unit tests' runtime (#6992)
  * Bump dependencies (#6998)
  * Add support for us-iso-west-1 region
  * Update Ginkgo
  * Replace deprecated Ginkgo CLI options
  * Add validations for managed nodegroup labels (#6947)
  * Fix merge release workflow when there is nothing to merge
  * Set region when config file is not supplied
  * Revert "Set default volume type for ISO regions"
  * Prepare for next development iteration
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.154.0:
  * Release notes for 0.154.0
  * Bump actions/setup-go from 4.0.1 to 4.1.0
  * Bump aws-actions/amazon-ecr-login from 1.6.2 to 1.7.0
  * Fix error message for Bottlerocket validation
  * Add references to Enterprise support with Flux on Gitops page
    (#6968)
  * Don't wait for aws-efs-csi-driver if cluster has no nodegroups
    (#6960)
  * Bring Windows integration test runtime down to less than half
  * Prepare for next development iteration (#6953)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.153.0:
  * Add release notes for 0.153.0 (#6948)
  * Bump dependencies
  * Bump dependencies and Update build image tag
  * Unit test creating the EKS provider (#6875)
  * Update Bottlerocket image version on nodegroup upgrade (#6923)
  * Remove PR rebase workflow (#6934)
  * Allow setting cluster-dns-ip for Bottlerocket
  * Improve error message when `overrideBootstrapCommand` is
    required for `customAMIs` (#6897)
  * Prepare for next development iteration
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.152.0:
  * Release notes for 0.152.0
  * Bump dependencies
  * Fix PR Rebase workflow (#6903)
  * Replace deprecated field
  * Bump dependencies
  * Update announcement
  * Add support for Tel Aviv (il-central-1)
  * Remove typo
  * Update workflows with pinned sha
  * Remove iam:ListInstanceProfiles from the required permissions
    list (#6898)
  * Bump dependencies
  * Prepare for next development iteration
  * Add option to print specific events when running `eksctl
    describe-stacks` (#6851)
  * Fix k8s.io/kubernetes version
* Sun Aug  6 2023 kastl@b1-systems.de
- Update to version 0.151.0:
  * Add release notes for 0.151
  * Bump dependencies (#6859)
  * Support custom Ubuntu AMIs for EKS-managed nodegroups (#6850)
  * Bump dependencies
  * Fix error with tar in `Post Cache go-build and mod` step
  * Fix setting link-time variables for release version
  * Cleanup Flux Integration (#6836)
  * Removing unused workflow
  * Paginate DescribeInstanceTypeOfferings response (#6832)
  * Add tests for PowerShell utils
  * Support custom AMIs for self-managed Windows nodegroups
  * Select one subnet for AZs where multiple are present and no VPC
    config provided (#6814)
  * Prepare for next development iteration (#6833)
  * go fmt
  * deprecated 1.22
* Thu Jul 20 2023 kastl@b1-systems.de
- Update to version 0.150.0:
  * Bump dependencies (#6830)
  * Update release notes for 0.150 (#6829)
  * Free up disk space in release workflow before building binaries
    (#6827)
  * Remove mockery config from dockerignore (#6828)
  * Update measurement id for GA
  * Bump mockery from 2.30.17 to 2.32.0 (#6819)
  * remove duplicate
  * Release notes for 0.150.0
  * Regenerate mocks
  * Migrate to mockery v2
  * Bundle dependabot updates
  * Updated links with both blog posts
  * Add announcement for transfer to new Github Organisation
  * Bump dependencies (#6803)
  * Add manual push-build-image workflow
  * Update image repository to ECR in workflows
  * Add ECR publish workflow
  * Update description on image repo
  * Prepare for next development iteration
* Thu Jul 13 2023 kastl@b1-systems.de
- Update to version 0.149.0:
  * Fix origin check in release script (#6800)
  * Release notes for 0.149.0
  * Bump dependencies (#6788)
  * Fix AWS_REGION and AWS_DEFAULT_REGION support for eksctl
    commands (#6787)
  * Undo changes to tag-common.sh
  * Update generated files
  * Update current github urls with new org urls
  * Fix generating mocks for aws-sdk-go-v2 interfaces
  * Revert "Support for Inf2 and trn1n instance types"
  * Pin K8s dependencies chain to 1.25 (#6677)
  * Adding Inf2 and trn1n support
  * Prepare for next development iteration
* Sat Jul  8 2023 kastl@b1-systems.de
- Update to version 0.148.0:
  * Add release notes for 0.148
  * Update documentation
  * Replaced weaveworksbot with eksctlbot in workflows and actions
  * Fix S3 endpoint for aws-iso-b
  * Fix Karpenter test
  * Fix support for fully-private clusters for ISO regions
  * Set default volume type for ISO regions
  * Refactor handling of partitions, fix validating partition
  * Fix unit tests
  * Add support for us-iso-east-1 and us-isob-east-1 regions
  * Bump dependencies (#6754)
  * resource should be nil if not found (#6756)
  * Migrate to sdk v2 - configuration loading (#6432)
  * Bump dependencies (#6742)
  * Fix documentation for EKS interface endpoint
  * Added new logo and favicon assets
  * Prepare for next development iteration
* Fri Jun 30 2023 kastl@b1-systems.de
- Update to version 0.147.0:
  * Release notes for 0.147.0
  * add identity action to update-generated workflow
  * Use nodeAffinity to determine if an addon supports ARM64
    (#6695)
  * Bump github.com/aws/aws-sdk-go from 1.44.286 to 1.44.288
  * Prepare for next development iteration (#6703)
  * coredns probes got mixed up for kubernetes 1.26 (#6707)
  * Bump dependencies
  * Update docs with `preserve` option to create addon
* Fri Jun 23 2023 kastl@b1-systems.de
- Update to version 0.146.0:
  * add documentation section in release notes
  * Release notes for 0.146.0
  * Updated slack urls for new k8s slack channel
  * chore: update vpc cni to be compatible with k8s >1.25
  * Bump docker/metadata-action from 4.5.0 to 4.6.0
  * Bump dependencies
  * Prepare for next development iteration
* Fri Jun 16 2023 kastl@b1-systems.de
- Update to version 0.145.0:
  * Add notes for release 0.145.0 (#6678)
  * Bump dependencies (#6674)
  * Added configurable output stream (#6675)
  * 'gofmt'-ed pkg/cfn/builder/statement.go
  * Updated wellKnownPolicy for Cluster Autoscaler and LoadBalancer
    Controller
  * Prepare for next development iteration
  * Update release notes
  * remove snap installation
  * cleanup of readme and contributing docs, fixed formatting and
    typos
* Mon Jun 12 2023 kastl@b1-systems.de
- Update to version 0.144.0:
  * Add release notes for 0.144
  * Add integration tests for resource-based hostnames (#6659)
  * Only retry appropriate errors (#6645)
  * Excluding email from link checker
  * Allow creating subnets with resource-based hostnames (#6651)
  * Added manual changes
  * Updated IAM policy statement for loadbalancer controller
  * Bump github.com/aws/aws-sdk-go from 1.44.268 to 1.44.271
  * Fix logging stack events logic (#6649)
  * Generated ATTRIBUTIONS.md file
  * Set default Windows volume name to /dev/sda1 (#6638)
  * Upgraded schemer from v0.0.0-2021 to v0.0.0-2023
  * Upgrade sourcegraph/go-diff from 0.6.2 to 0.7.1
  * Updated bufpipe dependency from 1.0.3 to 1.0.4
  * Prepare for next development iteration
  * port Add ready plugin to CoreDNS and use health.lameduck for a
    safer shutdown to 1.27
  * port Add ready plugin to CoreDNS and use health.lameduck for a
    safer shutdown to 1.25 and 1.26
  * port Add ready plugin to CoreDNS and use health.lameduck for a
    safer shutdown to 1.25 and 1.26
  * Use `%%w` verb for errors
  * address code review suggestions
  * fix to clean up ALB security groups
  * fix to clean up ALBs using IngressClassName
* Sat May 27 2023 kastl@b1-systems.de
- Update to version 0.143.0:
  * updated some dependencies
  * Release 0.143.0
  * Add support for EKS 1.27 (#6639)
  * Revert "Revert defaulting to IMDSv2  (#6624)" (#6631)
  * Fix readiness probe in HTTP test (#6628)
  * Added Amine and YuXiang to coreteam
  * Prepare for next development iteration (#6626)
* Wed May 24 2023 kastl@b1-systems.de
- Update to version 0.142.0:
  * Add release notes for 0.142.0 (#6623)
  * Revert defaulting to IMDSv2  (#6624)
  * Fix CRUD and Managed integration tests (#6622)
  * Update config file examples to reflect amiFamily is required
    with custom AMI (#6617)
  * Update integration tests and userdocs references to IMDSv1
    (#6618)
  * Make IMDSv2 the default (#6612)
  * update sts.go
  * Update build image manifest, tag file and workflows
  * updated dependencies
  * Add TagResource perm to EFS wellknown policy
  * Revert "Adding support for inf2 and trn1n instances"
  * Bump dependencies
  * Prepare for next development iteration
  * Adding support for inf2 and trn1n instances
* Fri May 12 2023 kastl@b1-systems.de
- Update to version 0.141.0:
  * release notes for 0.141.0
  * Update vpc-configuration.md (#6569)
  * Prepare for next development iteration
* Fri May  5 2023 kastl@b1-systems.de
- Update to version 0.140.0:
  * Add release notes for 0.140.0 (#6560)
  * Only select AZs that support all instance types on nodegroup
    creation (#6464)
  * Update schema.json
  * updated deps and schema
  * Force kubeconfig get-token output format to json
  * Revert "Temporarily remove failing Bottlerocket upgrade test
    (#6540)"
  * Bump lycheeverse/lychee-action from 1.6.1 to 1.7.0
  * Prepare for next development iteration
* Fri Apr 28 2023 kastl@b1-systems.de
- Update to version 0.139.0:
  * Release notes for 0.139.0
  * Security Policy for eksctl project
  * Temporarily remove failing Bottlerocket upgrade test (#6540)
  * Update userdocs/src/usage/eks-private-cluster.md
  * Bump golang.org/x/crypto from 0.7.0 to 0.8.0
  * fix flux version validation
  * Improve installation instructions
  * Prepare for next development iteration
  * Fix nesting of info text
  * Added EKS interface endpoint support to eks-private-cluster.md
* Fri Apr 21 2023 kastl@b1-systems.de
- Update to version 0.138.0:
  * Add release notes for 0.138
  * Bump dependencies (#6525)
  * Add support for EKS 1.26 (#6502)
  * Add volcano podgroups permissions (#6500)
  * Prepare for next development iteration
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.137.0:
  * Add release notes for 0.137.0 (#6496)
  * Fix crud int test (#6497)
  * Add scale nodegroup integration test with wait flag and fix old
    flakes (#6495)
  * Add wait flag to `scale nodegroup` (#6406)
  * Add support for Spot Interruption Queue within Karpenter
    (#6460)
  * Bump github.com/docker/docker
  * added two more domains to ignore for link checker
  * Update build image manifest, tag file and workflows
  * Update userdocs/src/usage/eksctl-karpenter.md
  * Update eksctl-karpenter.md
  * Prepare for next development iteration
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.136.0:
  * removed the Karpenter PR since it'll be reverted
  * Release 0.136.0
  * Revert "Update Karpenter CFN template to support Spot
    Interruption Queue (#6453)" (#6457)
  * Update Karpenter CFN template to support Spot Interruption
    Queue (#6453)
  * Fix panic when a nodegroup element is not set in ClusterConfig
    (#6443)
  * Log stack events on integration test failure (#6450)
  * Update actions and deps
  * Prepare for next development iteration
* Fri Mar 24 2023 kastl@b1-systems.de
- Update to version 0.135.0:
  * Add release notes for 0.135.0 (#6439)
  * Update addon example with ebs addon (#6438)
  * [Upgrade nodegroup via EKS API] Make AMI release version
    customisable (#6340)
  * Add m7g and r7g as ARM instance types (#6436)
  * deps update + updated outposts page
  * Handle deprecated AMIs when scaling self-managed nodegroups
  * Fix a typo in an error message (#6431)
  * Bump dependencies
  * Prepare for next development iteration
  * Update userdocs/src/usage/cloudwatch-cluster-logging.md
  * Update userdocs/src/usage/cloudwatch-cluster-logging.md
  * Update userdocs/src/usage/cloudwatch-cluster-logging.md
  * update: cloudwatch log descriptions
* Fri Mar 17 2023 kastl@b1-systems.de
- Update to version 0.134.0:
  * Add new region to docs
  * Add release notes for 0.134.0
  * Add support for Melbourne (ap-southeast-4)
  * Fix cluster argument in addons integration tests (#6397)
  * reworded the KMS encryption page with more upto date info and
    avoid broken link
  * make EKS 1.25 default
  * Add integration tests for addons in a cluster with no nodes
    (#6378)
  * Update build image manifest, tag file and workflows
  * Improve messages during creation of iamserviceaccount (#5856)
  * fix the image in coredns asset
  * Add condition to restrict fargate pod execution role to source
    arn (#6375)
  * Prepare for next development iteration (#6380)
* Fri Mar 10 2023 kastl@b1-systems.de
- Update to version 0.133.0:
  * Release notes for 0.133.0
  * [Upgrade nodegroup via EKS API] Don't specify kubernetes
    version when using a custom AMI (#6318)
  * Bump github.com/aws/aws-sdk-go from 1.44.209 to 1.44.210
    (#6370)
  * Bump lycheeverse/lychee-action from 1.5.4 to 1.6.1 (#6361)
  * Improve bottlerocket integration tests - custom AMI and GPU
    support (#6347)
  * Bump dependencies
  * Use addons published by AWS EKS for describe-addon-versions
  * Prepare for next development iteration (#6339)
* Sun Mar  5 2023 Johannes Kastl <kastl@b1-systems.de>
- new package eksctl: The official CLI for Amazon EKS
